<?php

// Gutenberg block
function diff_check_register_block() {
    if (!function_exists('register_block_type')) {
        return;
    }

    $block_name = 'diff-check/block';
    $block_script_handle = 'diff-check-block-script';
    $block_style_handle = 'diff-check-block-style';
    wp_register_script(
        $block_script_handle,
        plugin_dir_url(__FILE__) . 'js/diff_check_block.js',
        array('wp-blocks', 'wp-element', 'wp-editor'),
        filemtime(plugin_dir_path(__FILE__) . 'js/diff_check_block.js')
    );
    wp_register_style(
        $block_style_handle,
        plugin_dir_url(__FILE__) . 'css/diff_check_block.css',
        array(),
        filemtime(plugin_dir_path(__FILE__) . 'css/diff_check_block.css')
    );
    register_block_type($block_name, array(
        'editor_script' => $block_script_handle,
        'editor_style' => $block_style_handle,
        'render_callback' => 'diff_check_block_render',
        'attributes' => array(
            'text1' => array(
                'type' => 'string',
                'default' => ''
            ),
            'text2' => array(
                'type' => 'string',
                'default' => ''
            ),
            'file1' => array(
                'type' => 'string',
                'default' => ''
            ),
            'file2' => array(
                'type' => 'string',
                'default' => ''
            ),
        ),
    ));
}
add_action('init', 'diff_check_register_block');

function diff_check_block_render($attributes) {
    $text1 = $attributes['text1'];
    $text2 = $attributes['text2'];

    if ($attributes['file1'] != '') {
        $text1 = file_get_contents($attributes['file1']);
    }

    if ($attributes['file2'] != '') {
        $text2 = file_get_contents($attributes['file2']);
    }

    // Convert texts to arrays of rows
    $rows1 = explode("\n", $text1);
    $rows2 = explode("\n", $text2);

    // Calculate the diff row by row
    $diff = '';
    $differences_count = 0;

    $numRows1 = count($rows1);
    $numRows2 = count($rows2);
    $numRows = max($numRows1, $numRows2);

    $diff .= '<table class="diff-check-table">';

    for ($i = 0; $i < $numRows; $i++) {
        $row1 = isset($rows1[$i]) ? $rows1[$i] : '';
        $row2 = isset($rows2[$i]) ? $rows2[$i] : '';

        $row1 = htmlspecialchars($row1, ENT_QUOTES | ENT_HTML5, 'UTF-8');
        $row2 = htmlspecialchars($row2, ENT_QUOTES | ENT_HTML5, 'UTF-8');

        $rowDiff = wp_text_diff($row1, $row2);

        // Handle rows with no differences in both text1 and text2
        if ($rowDiff === '') {
            // Add the structure to rows with no differences
        $rowDiff = '<table class="diff is-split-view"><tbody><tr><td class="diff-deletedline"><span aria-hidden="true" class="dashicons arrow-right-alt2"></span>' . $row1 . '</td><td class="diff-deletedline"><span aria-hidden="true" class="dashicons arrow-right"></span>' . $row2 . '</td></tr></td></tr></tbody></table>';
        } else {
            // Add the structure to rows with differences
            $rowDiff = '<tr>' . $rowDiff . '</tr>';
        }

        // Count differences
        if ($rowDiff !== '') {
            $differences_count++;
        }

        $diff .= $rowDiff;
    }

    $diff .= '</table>';

    return '<div class="diff-check">' . $diff . '</div><p>Differences found: ' . $differences_count . '</p>';
}

